@@ -1,8 +1,10 @@
 import os
 from shutil import which
 from .pipeline_config import load_config
+from .dl1ab_tuning import create_dl1ab_tuned_config
 
-__all__ = ["load_config"]
+
+__all__ = ["load_config", "create_dl1ab_tuned_config"]
 
 
 def export_env(outdir="."):
