@@ -1,4 +1,4 @@
-from .mc_r0_to_dl1 import r0_to_dl1, batch_r0_to_dl1
+from .mc_process_dl1 import r0_to_dl1, reprocess_dl1, batch_process_dl1
 from .mc_merge_and_copy_dl1 import merge_dl1, batch_merge_and_copy_dl1
 from .mc_train import train_pipe, batch_train_pipe, batch_plot_rf_features
 from .mc_dl1_to_dl2 import dl1_to_dl2, batch_dl1_to_dl2
@@ -7,7 +7,8 @@ from .mc_dl2_to_sensitivity import dl2_to_sensitivity, batch_dl2_to_sensitivity
 
 __all__ = [
     "r0_to_dl1",
-    "batch_r0_to_dl1",
+    "reprocess_dl1",
+    "batch_process_dl1",
     "merge_dl1",
     "batch_merge_and_copy_dl1",
     "train_pipe",
