@@ -5,10 +5,11 @@
 # lstMCpipe DL1 to DL2 onsite stage (at La Palma cluster)
 
 import os
+import time
 import shutil
 import logging
-import time
 from lstmcpipe.io.data_management import check_and_make_dir_without_verification
+from lstmcpipe.workflow_management import save_log_to_file
 
 
 log = logging.getLogger(__name__)
@@ -22,7 +23,8 @@ def batch_dl1_to_dl2(
     jobids_from_merge,
     dict_with_dl1_paths,
     particles_loop,
-    source_env,
+    batch_config,
+    logs,
     gamma_offsets=None,
 ):
     """
@@ -46,10 +48,13 @@ def batch_dl1_to_dl2(
         Indeed the log of the merge_and_copy stage, where the final names of the dl1 files were stored
     particles_loop : list
         list with the particles to be processed. Takes the global variable ALL_PARTICLES
-    source_env : str
-        source environment to select the desired conda environment to run train_pipe and dl1_to_dl2 stages
+    batch_config : dict
+        Dictionary containing the (full) source_environment and the slurm_account strings to be passed to
+        dl1_dl2 function
     gamma_offsets : list
         list off gamma offsets
+    logs: dict
+        Dictionary with logs files
 
     Returns
     -------
@@ -57,8 +62,6 @@ def batch_dl1_to_dl2(
         Dictionary containing the log of the batched dl1_to_dl2 jobs
     jobid_4_dl2_to_dl3 : str
         string containing the jobids to be passed to the next stage of the workflow (as a slurm dependency)
-    debug_log : dict
-        Debug and summary purposes
 
     """
 
@@ -83,7 +86,7 @@ def batch_dl1_to_dl2(
                     wait_jobid_train_pipe=jobid_from_training,
                     wait_jobids_merge=jobids_from_merge,
                     dictionary_with_dl1_paths=dict_with_dl1_paths,
-                    source_environment=source_env,
+                    batch_configuration=batch_config,
                 )
 
                 log_dl1_to_dl2.update(job_logs)
@@ -103,7 +106,7 @@ def batch_dl1_to_dl2(
                 wait_jobid_train_pipe=jobid_from_training,
                 wait_jobids_merge=jobids_from_merge,
                 dictionary_with_dl1_paths=dict_with_dl1_paths,
-                source_environment=source_env,
+                batch_configuration=batch_config,
             )
 
             log_dl1_to_dl2.update(job_logs)
@@ -116,9 +119,12 @@ def batch_dl1_to_dl2(
 
     jobid_4_dl2_to_dl3 = ",".join(jobid_for_dl2_to_dl3)
 
+    save_log_to_file(log_dl1_to_dl2, logs["log_file"], workflow_step="dl1_to_dl2")
+    save_log_to_file(debug_log, logs["debug_file"], workflow_step="dl1_to_dl2")
+
     log.info("==== END {} ====".format("batch dl1_to_dl2_workflow"))
 
-    return log_dl1_to_dl2, jobid_4_dl2_to_dl3, debug_log
+    return log_dl1_to_dl2, jobid_4_dl2_to_dl3
 
 
 def dl1_to_dl2(
@@ -129,7 +135,7 @@ def dl1_to_dl2(
     wait_jobid_train_pipe=None,
     wait_jobids_merge=None,
     dictionary_with_dl1_paths=None,
-    source_environment=None,
+    batch_configuration='',
 ):
     """
     Convert onsite files from dl1 to dl2
@@ -151,9 +157,9 @@ def dl1_to_dl2(
         string with merge_and_copy jobids
     dictionary_with_dl1_paths : dict
         Dictionary with 'particles' as keys containing final output filenames of dl1 files.
-    source_environment : str
-        path to a .bashrc file to source (can be configurable for custom runs @ mc_r0_to_dl3 script) to activate
-        a certain conda environment.
+    batch_configuration : dict
+        Dictionary containing the (full) source_environment and the slurm_account strings to be passed to the
+        sbatch commands
         ! NOTE : train_pipe AND dl1_to_dl2 MUST BE RUN WITH THE SAME ENVIRONMENT
 
     Returns
@@ -167,6 +173,8 @@ def dl1_to_dl2(
         workflow (dl2_to_irfs)
 
     """
+    source_environment = batch_configuration["source_environment"]
+    slurm_account = batch_configuration["slurm_account"]
 
     output_dir = input_dir.replace("DL1", "DL2")
     log.info("Working on DL1 files in {}".format(input_dir))
@@ -178,7 +186,7 @@ def dl1_to_dl2(
 
     # path to dl1 files by particle type
     file_list = [
-        dictionary_with_dl1_paths[particle]["testing"]["test_path_and_outname_dl1"],
+        dictionary_with_dl1_paths[particle]["testing"]["test_path_and_outname_dl1"]
     ]
 
     return_jobids = []
@@ -203,10 +211,8 @@ def dl1_to_dl2(
 
     for file in file_list:
 
-        cmd = ""
-        if source_environment is not None:
-            cmd += source_environment
-        cmd += f"lstchain_dl1_to_dl2 -f {file} -p {path_models} -o {output_dir}"
+        cmd = f"{source_environment} lstchain_dl1_to_dl2 -f {file} -p {path_models}" \
+              f" -o {output_dir}"
 
         if config_file is not None:
             cmd += f" -c {config_file}"
@@ -215,6 +221,7 @@ def dl1_to_dl2(
         # if dry_run:
         #     print(cmd)
 
+        # Only applying dl1_to_dl2 stage to test files
         if "testing" in file:
             ftype = "test"
         else:
@@ -224,21 +231,22 @@ def dl1_to_dl2(
         jobo = os.path.join(output_dir, f"dl1_dl2_{particle}_{ftype}job.o")
 
         # sbatch --parsable --dependency=afterok:{wait_ids_proton_and_gammas} --wrap="{cmd}"
-        batch_cmd = (
-            f"sbatch --parsable -p short --dependency=afterok:{wait_jobs} -J {job_name[particle]}"
-            f' -e {jobe} -o {jobo} --wrap="{cmd}"'
+        batch_cmd = "sbatch --parsable -p short --mem=32G"
+        if slurm_account != "":
+            batch_cmd += f" -A {slurm_account}"
+        batch_cmd += (
+            f" --dependency=afterok:{wait_jobs} -J {job_name[particle]} -e {jobe}"
+            f' -o {jobo} --wrap="{cmd}"'
         )
 
         # Batch the job at La Palma
         jobid_dl1_to_dl2 = os.popen(batch_cmd).read().strip("\n")
 
         log_dl1_to_dl2[particle][jobid_dl1_to_dl2] = batch_cmd
-        if (
-            "testing" in file
-        ):  # TODO to be done to 'training' files too ? Should not be necessary
+        if "testing" in file:
             log_dl1_to_dl2[particle]["dl2_test_path"] = file.replace(
                 "/DL1/", "/DL2/"
-            ).replace("dl1_", "dl2_")
+            ).replace("dl1_", "dl2_", 1)
         return_jobids.append(jobid_dl1_to_dl2)
 
     if config_file is not None:
